@@ -3,12 +3,16 @@ mod mod_conf;
 mod zhiyan_proto;
 
 use serde_json::Value;
-use std::{thread, time::Duration};
+use std::{fs, thread, time::Duration};
 use tokio::runtime::Builder;
 use tonic::Request;
 use zhiyan_proto::upload_client::UploadClient;
 use zhiyan_proto::UploadRequest;
 
+pub fn path_exists(path: &str) -> bool {
+    fs::metadata(path).is_ok()
+}
+
 pub fn send_request_json(json_value: Value) -> Result<(), ureq::Error> {
     let args: Vec<String> = std::env::args().collect();
     let conf_filename = &args[1];
